pub enum Message {
System(SystemMessage),
User {
application_id: ApplicationId,
bytes: Vec<u8>,
},
}Expand description
A message to be sent and possibly executed in the receiver’s block.
Variants
System(SystemMessage)
A system message.
User
A user message (in serialized form).
Fields

application_id: ApplicationIdThe ID of the application this message targets.
Implementations
Sourceimpl Message
impl Message
Sourcepub fn system(message: SystemMessage) -> Self
pub fn system(message: SystemMessage) -> Self
Creates a new system message.
Sourcepub fn user<A, M: Serialize>(
application_id: ApplicationId<A>,
message: &M,
) -> Result<Self, Error>
pub fn user<A, M: Serialize>( application_id: ApplicationId<A>, message: &M, ) -> Result<Self, Error>
Creates a new user application message assuming that the message is valid for the
application_id.
Sourcepub fn application_id(&self) -> GenericApplicationId
pub fn application_id(&self) -> GenericApplicationId
Returns the ID of the application this message targets.