pub enum Query {
System(SystemQuery),
User {
application_id: ApplicationId,
bytes: Vec<u8>,
},
}Expand description
An query to be sent and possibly executed in the receiver’s block.
Variants
System(SystemQuery)
A system query.
User
A user query (in serialized form).
Fields

application_id: ApplicationIdThe ID of the application this query targets.
Implementations
Sourceimpl Query
impl Query
Sourcepub fn system(query: SystemQuery) -> Self
pub fn system(query: SystemQuery) -> Self
Creates a new system query.
Sourcepub fn user<A: Abi>(
application_id: ApplicationId<A>,
query: &A::Query,
) -> Result<Self, Error>
pub fn user<A: Abi>( application_id: ApplicationId<A>, query: &A::Query, ) -> Result<Self, Error>
Creates a new user application query following the application_id’s Abi.
Sourcepub fn user_without_abi(
application_id: ApplicationId,
query: &impl Serialize,
) -> Result<Self, Error>
pub fn user_without_abi( application_id: ApplicationId, query: &impl Serialize, ) -> Result<Self, Error>
Creates a new user application query assuming that the query is valid for the
application_id.
Sourcepub fn application_id(&self) -> GenericApplicationId
pub fn application_id(&self) -> GenericApplicationId
Returns the ID of the application this query targets.