pub struct MessageContext {
pub chain_id: ChainId,
pub origin: ChainId,
pub is_bouncing: bool,
pub authenticated_signer: Option<AccountOwner>,
pub refund_grant_to: Option<Account>,
pub height: BlockHeight,
pub round: Option<u32>,
pub timestamp: Timestamp,
}Expand description
The context in which a message is executed.
Fields
chain_id: ChainIdThe current chain ID.
origin: ChainIdThe chain ID where the message originated from.
is_bouncing: boolWhether the message was rejected by the original receiver and is now bouncing back.
authenticated_signer: Option<AccountOwner>The authenticated signer of the operation that created the message, if any.
refund_grant_to: Option<Account>Where to send a refund for the unused part of each grant after execution, if any.
height: BlockHeightThe current block height.
round: Option<u32>The consensus round number, if this is a block that gets validated in a multi-leader round.
timestamp: TimestampThe timestamp of the block executing the message.